# Credits

## Development Lead
----------------

* plague <plague_anon@protonmail.com>


## Contributors
------------
* imsi      | Anonops IRC #python

### Special thanks to
* Audreyr   | https://github.com/audreyr/cookiecutter
* rootVIII  | https://github.com/rootVIII/proxy_requests
